#!/usr/bin/perl
#
# $Header: //sapdb/V76/develop/sys/src/install/perl/SAPDB/Install/Control/StaticBitmap.pm#2 $
# $DateTime: 2005/07/28 15:16:36 $
# $Change: 103183 $
#
# Desc: 

package SAPDB::Install::Control::StaticBitmap;

use Wx::Event qw (EVT_PAINT);
use Wx qw ( wxAND wxAND_INVERT wxAND_REVERSE
		   wxCLEAR wxCOPY wxEQUIV wxINVERT wxNAND
		   wxNOR wxNO_OP wxOR wxOR_INVERT
		   wxOR_REVERSE wxSET wxSRC_INVERT wxXOR);

use base Wx::PlWindow;


sub new{
	my $self = shift->SUPER::new(@_);
	$self->SetBackgroundColour($self->GetParent->GetBackgroundColour());
	EVT_PAINT($self,\&OnPaint);
	return $self;
}

sub SetBmp{	
	my ($self,$bmp) = @_;
	unless(defined $self->{'mdc'}){
		$self->{'mdc'} = Wx::MemoryDC->new();
	}
	$self->{'mdc'}->SelectObject($bmp);
	$self->SetSize($self->{'mdc'}->GetSizeWH);
	return 1;
}

sub SetInvBmp{
	my ($self,$bmp) = @_;
	unless(defined $self->{'imdc'}){
		$self->{'imdc'} = Wx::MemoryDC->new();
	}
	$self->{'imdc'}->SelectObject($bmp);
	$self->SetSize($self->{'imdc'}->GetSizeWH);
	return 1;
}


sub SetBmpFromResource{
	my ($self,$res_file,$name) = @_;
	my $image = SAPDB::Install::Resource->new($res_file)->getImages($name);
	unless(defined $image || exists $image->{$name}){
		return undef;
	}
	return $self->SetBmpFromImage($image->{$name});
}

sub SetBmpFromImage{
	my ($self,$image) = @_;
	my $i = 0;
	my $size = $image->GetHeight * $image->GetWidth; 
	my $new_image = $image->Copy;
	my $data = $new_image->GetData();
	my $new_data;
	my $transvalue;
	while($i < ($size)){
		my $pixel = substr($data,$i*3,3); 
		my ($r,$g,$b) = unpack('CCC',$pixel);
		if($i == 0){
			$transvalue = $pixel;
		}
		if($transvalue eq $pixel){
			substr($new_data,$i * 3) = $pixel;
			$i++;
			next;
		}
		$r = $g = $b = ($r + $g + $b) / 3;
		substr($new_data,$i * 3) = pack('CCC',$r,$g,$b);
		$i++;
	}
	$new_image->SetData($new_data);
	$self->SetInvBmp(Wx::Bitmap->new($new_image));	
	return $self->SetBmp(Wx::Bitmap->new($image));	
}

sub Invert{
	my ($self) = @_;
	if($self->{'invert'}){
		$self->{'invert'} = 0;
	}
	else{
		$self->{'invert'} = 1; 
	}
	$self->Refresh;
	$self->Update;
}


sub OnPaint{
	my ($self,$evt) = @_;
	return undef unless (defined $self->{'mdc'}); 
	my $pdc = Wx::PaintDC->new($self);
	if($self->{'invert'} and defined $self->{'imdc'}){
		$pdc->Blit(0,0,
			   $self->{'imdc'}->GetSizeWH,
			   $self->{'imdc'},0,0,
			   wxCOPY,
			   1);
	}
	else{
		$pdc->Blit(0,0,
			   $self->{'mdc'}->GetSizeWH,
			   $self->{'mdc'},0,0,
			   wxCOPY,1);
	}
	$evt->Skip;
}

sub Destroy{
	my ($self) = @_;
	if(exists $self->{'mdc'}){
		delete $self->{'mdc'};
	}
	if(exists $self->{'imdc'}){
		delete $self->{'imdc'};
	}
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	print ">>>>> destroying $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}


1;