#!/usr/bin/perl
#
# $Header: //sapdb/V76/develop/sys/src/install/perl/SAPDB/Install/Instance/Check/DomainUser.pm#6 $
# $DateTime: 2005/07/27 08:40:37 $
# $Change: 103032 $
#

package SAPDB::Install::Instance::Check::DomainUser;

use SAPDB::Install::Instance::Base;
use SAPDB::Install::Instance::Check::Conditions;

push @ISA, 
	'SAPDB::Install::Instance::Base',
	'SAPDB::Install::Instance::Check::Conditions';

sub domainuser {
	my ($self) = @_;
	my $dbm = $self->{dbm};

	#
	# find out instance type if not already known
	#
	unless (
	defined $self->{'instancetype'} &&
	defined $self->{'starting_release'}) {
		my $rc = $self->conditions ();
		return undef unless (defined $rc && $rc == 0);
	}

    # no domain user in 7.6. always return 0 in this case!
	my $startingRelease = $self->{starting_release};
	if( $startingRelease and $startingRelease =~ /\s*7\.(\d+)/ and $1 >= 6){
		$self->set_errorstate ('OK');
		return 0;
	}

	$self->set_errorstate ('ERROR');
	$self->msgbegin ("looking for domain user");	
	$self->msg0 ("looking for domain user...\n");

	my $userlist = $dbm->user_getall ();
	unless (defined $userlist) {
		$self->msg1 ("\n");
		$self->msg1 ($dbm->lastdialog ());
		$self->msgend ();
		return undef;
	}

	$self->msg1 ("user profile container contains:\n");
	$self->msg1 ("\n");
	foreach my $user (@$userlist) {
		$self->msg1 ("  ".$user."\n");
	}
	$self->msg1 ("\n");

	foreach my $user (@$userlist) {
		if ($user =~ /^domain$/i) {
			$self->msg1
			("found domain user in user profile container\n");
			$self->set_errorstate ('OK');
			$self->msgend ();
			return 0;
		}
	}

	$self->msg1 ("domain user not found in user profile container\n");
	$self->msg1 ("unable to load system tables\n");
	$self->msg1 ("\n");
	$self->msg1 ("load system tables and run SDBUPD again\n");
	$self->msg1 ("\n");

	$self->msgend ();
	return undef;
} 

1;

